<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.2 (2017/02/13)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.10+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/search_records_helper.php';

class Search_filehtml_helper extends Search_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_writer_rights = array(); // Droits du rédacteur
    protected $_doc_infos = array('name' => 'filehtml', 'type' => 'filehtml'); // Tableau contenant les informations du document (nom, type)
    //

	// --------------------------------------------------------------------

    /*
     * Constructeur
     */
    public function __construct($writer_rights)
    {
        parent :: __construct($this -> _doc_infos, $writer_rights);

        $this -> CI -> load_addon_helper('filehtml', 'plugin_menu_for_filehtml_helper');
        $this -> CI -> load_addon_helper('filehtml', 'filehtml_infos_helper');

        $this -> CI -> load_addon_model('filehtml', 'filehtml_ids_model');
 //       $this -> CI -> load_addon_model('filehtml', 'writer_filehtml_model', array('id' => $this -> _writer_rights['id']));

        $this -> CI -> load_addon_lang('filehtml');
        $this -> CI -> load_addon_config('filehtml');        

        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();    
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */
    
	// --------------------------------------------------------------------

    public function search()
    {
        return parent :: search();   
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {        
        $parent_addons = parent :: set_header_addons();
        
        $js = '';

        $css = '';

        return $parent_addons.$css.$js;        
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['search_'.$this -> _doc_infos['name']]); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
	 * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return '';
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_for_filehtml_helper :: set_admin_items('filehtml', $this -> _lang, $this -> _config, $this -> _writer_rights);
        } else {
            return Plugin_menu_for_filehtml_helper :: set_public_items('filehtml', $this -> _lang, $this -> _config, $this -> _writer_rights);
        }
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    public function set_infos_plugin()
    {
        return Filehtml_infos_helper :: set_plugin_infos($this -> _lang);
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = array_merge(parent :: _set_params(),
            array(
                'writerid'  => Var_helper :: import('writerid', 'post', array(), array('trim')),
            )
        );
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_search_records_view()
    {
        return parent :: _get_layout_for_search_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * Retourne la liste des documents du rédacteur
     * 
	 * @access private
	 * @return mixed Code html
	 */
    protected function _get_writer_docs()
    {
        $docs = array();
        
        $docs = $this -> CI -> filehtml_ids_model -> get(array('author_id' => $this -> _writer_rights['id'], 'status' => array('a', 'i')));
        
/*        if (ADMR_IS_ADMIN !== TRUE) {
            $docs = array_intersect_key(
                $docs,
                $this -> CI -> writer_filehtml_model -> get()        
            );           
        }
*/        
        foreach($docs as $key => $doc) {
            $docs[$key]['heading'] = $this -> _config['lang'][1] == ADMR_LNG ? $doc['title2'] : $doc['title1'];    
        }
        
        return $docs;    
    }

	// --------------------------------------------------------------------

	/**
	 * Fait une redirection selon le résultat du filtre appliqué
	 *
	 * @access	protected
     * @param integer Identifiant du filtre appliqué
     * @param string Uri de redirection
	 * @return void
	 */
    protected function _redirect_by_filter($filter, $uri)
    {
		
        $uri = 'addons/filehtml/'.$uri;
        
        /**
		 * Sélection des quiz par leur type ($filter = 2)
		 */    
        $writerid = $this -> _params['writerid'];
        
        if ($filter == '2' && !empty($writerid)) {
            $uri .= is_array($writerid) ? '&writerid='.implode('-', $writerid) : ''; 
        }
        //
         
		/**
		 * Sélection des options de menu par défaut ($filter = 0) et par leurs identifiants ($filter = 1)
		 */    
        parent :: _redirect_by_filter($filter, $uri); // Filter = 0 et 1
        //
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne des données supplémentaires à faire passer à la vue
     * 
	 * @access protected
     * @return array Tableau de données à faire passer à la vue
	 */
    protected function _get_more_data_for_search_form()
    {
        return array(
            'writers' => (ADMR_IS_ADMIN) ? $this -> _get_writers() : array()
        );
    }   
 
	// --------------------------------------------------------------------

    /**
	 * Définit et retourne des données des rédacteurs
     * 
	 * @access protected
     * @return array Tableau de données à faire passer à la vue
	 */
    protected function _get_writers()
    {
        $this -> CI -> load_model('writer_model');

        $writers = $this -> CI -> writer_model -> get(array(), 'ch_asc');            
        
        return $writers;
    }   
   
	// --------------------------------------------------------------------

} // End of Class